Success
-------

General format of success response is:

::

  {
    code: 200,
    data: {"array or object"}
  }

Example:

::

  {
    code: 200,
    data: ["home", "about", "price", "contact"]
  }
